@@ -46,7 +46,7 @@ passenger_count: int8
 trip_distance: float
 pickup_longitude: float
 pickup_latitude: float
-rate_code_id: string
+rate_code_id: null
 store_and_fwd_flag: string
 dropoff_longitude: float
 dropoff_latitude: float
@@ -57,10 +57,6 @@ mta_tax: float
 tip_amount: float
 tolls_amount: float
 total_amount: float
-improvement_surcharge: float
-pickup_location_id: int32
-dropoff_location_id: int32
-congestion_surcharge: float
 year: int32
 month: int32
 
@@ -71,10 +67,11 @@ See $metadata for additional Schema metadata
 #  system.time(ds %>%
 #    filter(total_amount > 100, year == 2015) %>%
 #    select(tip_amount, total_amount, passenger_count) %>%
+#    mutate(tip_pct = 100 * tip_amount / total_amount) %>%
 #    group_by(passenger_count) %>%
 #    collect() %>%
-#    summarize(
-#      tip_pct = median(100 * tip_amount / total_amount),
+#    summarise(
+#      median_tip_pct = median(tip_pct),
 #      n = n()
 #    ) %>%
 #    print())
@@ -82,18 +79,18 @@ See $metadata for additional Schema metadata
 ## ---- echo = FALSE, eval = !file.exists("nyc-taxi")---------------------------
 cat("
 # A tibble: 10 x 3
-   passenger_count tip_pct      n
-             <int>   <dbl>  <int>
- 1               0    9.84    380
- 2               1   16.7  143087
- 3               2   16.6   34418
- 4               3   14.4    8922
- 5               4   11.4    4771
- 6               5   16.7    5806
- 7               6   16.7    3338
- 8               7   16.7      11
- 9               8   16.7      32
-10               9   16.7      42
+   passenger_count median_tip_pct      n
+             <int>          <dbl>  <int>
+ 1               0           9.84    380
+ 2               1          16.7  143087
+ 3               2          16.6   34418
+ 4               3          14.4    8922
+ 5               4          11.4    4771
+ 6               5          16.7    5806
+ 7               6          16.7    3338
+ 8               7          16.7      11
+ 9               8          16.7      32
+10               9          16.7      42
 
    user  system elapsed
   4.436   1.012   1.402
@@ -103,6 +100,7 @@ cat("
 #  ds %>%
 #    filter(total_amount > 100, year == 2015) %>%
 #    select(tip_amount, total_amount, passenger_count) %>%
+#    mutate(tip_pct = 100 * tip_amount / total_amount) %>%
 #    group_by(passenger_count)
 
 ## ---- echo = FALSE, eval = !file.exists("nyc-taxi")---------------------------
@@ -111,8 +109,9 @@ FileSystemDataset (query)
 tip_amount: float
 total_amount: float
 passenger_count: int8
+tip_pct: expr
 
-* Filter: ((total_amount > 100:double) and (year == 2015:double))
+* Filter: ((total_amount > 100) and (year == 2015))
 * Grouped by passenger_count
 See $.data for the source Arrow object
 ")
