@@ -20,20 +20,20 @@ context("install_arrow()")
 r_only({
   test_that("arrow_repos", {
     cran <- "https://cloud.r-project.org/"
-    bt <- "https://dl.bintray.com/ursalabs/fake_repo"
+    ours <- "https://dl.example.com/ursalabs/fake_repo"
     other <- "https://cran.fiocruz.br/"
 
-    old <- options(
+    opts <- list(
       repos=c(CRAN = "@CRAN@"),  # Restore defaul
-      arrow.dev_repo = bt
+      arrow.dev_repo = ours
     )
-    on.exit(options(old))
-
-    expect_identical(arrow_repos(), cran)
-    expect_identical(arrow_repos(c(cran, bt)), cran)
-    expect_identical(arrow_repos(c(bt, other)), other)
-    expect_identical(arrow_repos(nightly = TRUE), c(bt, cran))
-    expect_identical(arrow_repos(c(cran, bt), nightly = TRUE), c(bt, cran))
-    expect_identical(arrow_repos(c(bt, other), nightly = TRUE), c(bt, other))
+    withr::with_options(opts, {
+      expect_identical(arrow_repos(), cran)
+      expect_identical(arrow_repos(c(cran, ours)), cran)
+      expect_identical(arrow_repos(c(ours, other)), other)
+      expect_identical(arrow_repos(nightly = TRUE), c(ours, cran))
+      expect_identical(arrow_repos(c(cran, ours), nightly = TRUE), c(ours, cran))
+      expect_identical(arrow_repos(c(ours, other), nightly = TRUE), c(ours, other))
+    })
   })
 })
